# Changelog

## [2.0.0](https://github.com/vanducng/miu-mono/compare/miu-mono-v1.0.0...miu-mono-v2.0.0) (2025-12-31)


### ⚠ BREAKING CHANGES

* Package folder paths changed, but no API changes.

### Code Refactoring

* simplify package folder names ([08206dc](https://github.com/vanducng/miu-mono/commit/08206dc3d0d90c3a31bf45a4e78561df639c40be))

## [1.0.0](https://github.com/vanducng/miu-mono/compare/miu-mono-v0.1.0...miu-mono-v1.0.0) (2025-12-29)


### ⚠ BREAKING CHANGES

* **miu:** Package renamed from 'miu' to 'miu-mono' Users should now: pip install miu-mono

### Code Refactoring

* **miu:** rename meta-package from miu to miu-mono ([227cb7c](https://github.com/vanducng/miu-mono/commit/227cb7cee68d1b9c3fad627f9054c1ed8ceaf8f8))
